import { create } from "zustand";
import logger from "@/lib/logger";
import { adminCreateUser } from ".";
import { APIError, CreateUserOption, User } from "gitea-js";

interface AdminCreateUserState {
  user: User | null;
  error: APIError | null;
  loading: boolean;
  adminCreateUser: (body: CreateUserOption) => Promise<void>;
}

const adminCreateUserStore = create<AdminCreateUserState>((set) => ({
  user: null,
  error: null,
  loading: false,
  adminCreateUser: async (body: CreateUserOption) => {
    set({ loading: true, user: null, error: null });
    try {
      const result = await adminCreateUser(body);
      if (result.error) {
        set({ loading: false, user: null, error: result.error });
      } else {
        set({ loading: false, user: result.data, error: null });
      }
    } catch (error) {
      logger.error({ error }, "Error in adminCreateUserStore");
      set({
        loading: false,
        user: null,
        error: { message: "Error in Server" } as APIError,
      });
    }
  },
}));

export default adminCreateUserStore;
