import base64 from "base-64";
import { APIError, RequestParams, User } from "gitea-js";
import { callGiteaApi, gitea, GiteaApiResponse } from "@/lib/gitea";

export async function userGetCurrent(
  username: string,
  password: string
): Promise<GiteaApiResponse<User, APIError>> {
  const basicAuth = `Basic ${base64.encode(`${username}:${password}`)}`;
  const params: RequestParams = {
    headers: {
      Authorization: basicAuth,
    },
  };
  const context = { username, password };
  const result = await callGiteaApi(
    () => gitea.user.userGetCurrent(params),
    "Successfully retrieved current user",
    "Failed to retrieve current user",
    context
  );
  return result;
}
