import { create } from "zustand";
import logger from "@/lib/logger";
import { userGetCurrent } from ".";
import { APIError, User } from "gitea-js";

interface UserGetCurrentState {
  user: User | null;
  error: APIError | null;
  loading: boolean;
  userGetCurrent: (username: string, password: string) => Promise<void>;
}

const userGetCurrentStore = create<UserGetCurrentState>((set) => ({
  user: null,
  error: null,
  loading: false,
  userGetCurrent: async (username: string, password: string) => {
    set({ loading: true, user: null, error: null });
    try {
      const result = await userGetCurrent(username, password);
      if (result.error) {
        set({ loading: false, user: null, error: result.error });
      } else {
        set({ loading: false, user: result.data, error: null });
      }
    } catch (error) {
      logger.error({ error }, "Error in userGetCurrentStore");
      set({
        loading: false,
        user: null,
        error: { message: "Error in Server" } as APIError,
      });
    }
  },
}));
