import logger from "./logger";
import fetch from "cross-fetch";
import { APIError, giteaApi } from "gitea-js";

const gitea = giteaApi(process.env.GITEA_URL as string, {
  token: process.env.GITEA_TOKEN,
  customFetch: fetch,
});

interface GiteaApiResponse<D, E> {
  data: D | null;
  error: E | null;
}

async function callGiteaApi<D>(
  apiCall: () => Promise<GiteaApiResponse<D, APIError>>,
  successMessage: string,
  errorMessage: string,
  context?: Record<string, unknown>
): Promise<GiteaApiResponse<D, APIError>> {
  try {
    logger.info("Calling Gitea API");
    const response = await apiCall();
    logger.info({ context, response }, successMessage);
    return { data: response.data, error: response.error };
  } catch (err) {
    logger.error({ context, error: err }, errorMessage);
    const errorResponse = err as GiteaApiResponse<null, APIError>;
    const apiError = errorResponse.error;
    return { data: errorResponse.data, error: apiError };
  }
}

export { gitea, callGiteaApi };
export type { GiteaApiResponse };
